
class Box(object):
    def __init__(self, depth_in_meters=False):
        self.depth_in_meters = depth_in_meters
        self._max_lat = None
        self._min_lat = None
        self._max_lon = None
        self._min_lon = None
        self.max_depth = None
        self.min_depth = None

    @property
    def max_lat(self):
        return self._max_lat

    @max_lat.setter
    def max_lat(self, value):
        if value > 90 or value < -90:
            raise ValueError('{0} is not a valid latitude. Must be between -90 and -90'.format(value))
        self._max_lat = value

    @property
    def min_lat(self):
        return self._min_lat

    @min_lat.setter
    def min_lat(self, value):
        if value > 90 or value < -90:
            raise ValueError('{0} is not a valid latitude. Must be between -90 and 90'.format(value))
        self._min_lat = value

    @property
    def max_lon(self):
        return self._max_lon

    @max_lon.setter
    def max_lon(self, value):
        if value > 360 or value < -360:
            raise ValueError('{0} is not a valid longitude. Must be between -360 and 360'.format(value))
        self._max_lon = value

    @property
    def min_lon(self):
        return self._min_lon

    @min_lon.setter
    def min_lon(self, value):
        if value >= 360 or value <= -360:
            raise ValueError('{0} is not a valid longitude. Must be between -360 and 360'.format(value))
        self._min_lon = value
        
    def get_lat_str(self):
        if self.max_lat is None or self.min_lat is None:
            return ''
        if self.min_lat < 0:
            direction = 'S'
        else:
            direction = 'N'
            
        string = str(abs(self.min_lat)) + direction
        
        if self.max_lat != self.min_lat:
            if self.max_lat < 0:
                direction = 'S'
            else:
                direction = 'N'
            string += str(abs(self.max_lat)) + direction
        
        return string

    def get_lon_str(self):
        if self.max_lon is None or self.min_lon is None:
            return ''
        if self.min_lon < 0:
            direction = 'W'
        else:
            direction = 'N'

        string = str(abs(self.min_lon)) + direction

        if self.max_lon != self.min_lon:
            if self.max_lon < 0:
                direction = 'S'
            else:
                direction = 'N'
            string += str(abs(self.max_lon)) + direction
        return string

    def get_depth_str(self):
        if self.max_depth is None or self.min_depth is None:
            return ''

        if self.depth_in_meters:
            suffix = 'm'
        else:
            suffix = ''

        string = str(abs(self.min_depth)) + suffix

        if self.min_depth != self.max_depth:
            string += '-' + str(abs(self.max_depth)) + suffix
        return string


