import os
from autosubmit.config.log import Log

from box import Box
from earthdiagnostics import Diagnostic, TempFile, Utils


class AverageSection(Diagnostic):

    def __init__(self, data_manager, startdate, member, chunk, variable, domain, box):
        Diagnostic.__init__(self, data_manager)
        self.startdate = startdate
        self.member = member
        self.chunk = chunk
        self.variable = variable
        self.domain = domain
        self.box = box

    @classmethod
    def generate_jobs(cls, diags, options):
        num_options = len(options) - 1
        if num_options < 5:
            raise Exception('You must specify the variable and the box to average')
        if num_options > 6:
            raise Exception('You must specify between 5 and 6 parameters for the section average diagnostic')
        variable = options[1]
        box = Box()
        box.min_lon = int(options[2])
        box.max_lon = int(options[3])
        box.min_lat = int(options[4])
        box.max_lat = int(options[5])
        if num_options >= 6:
            domain = options[6]
        else:
            domain = 'ocean'

        job_list = list()
        for startdate in diags.startdates:
            for member in diags.members:
                for chunk in range(1, diags.chunks + 1):
                    job_list.append(AverageSection(diags.data_manager, startdate, member, chunk,
                                                   variable, domain, box))
        return job_list

    def compute(self):
        temp = TempFile.get()
        variable_file = self.data_manager.get_file(self.domain, self.variable, self.startdate, self.member, self.chunk,
                                                   grid='regular')
        Utils.cdo.zonmean(input='-sellonlatbox,{0},{1},{2},{3} {4}'.format(self.box.min_lon, self.box.max_lon,
                                                                           self.box.min_lat, self.box.max_lat,
                                                                           variable_file),
                          output=temp)
        os.remove(variable_file)
        self.data_manager.send_file(temp, self.domain, self.variable + 'mean', self.startdate, self.member, self.chunk,
                                    box=self.box, grid='regular')
        Log.info('Finished section average for startdate {0}, member {1}, chunk {2}',
                 self.startdate, self.member, self.chunk)
