from earthdiagnostics import Diagnostic, TempFile, cdftools, Utils


class Psi(Diagnostic):
    def __init__(self, data_manager, startdate, member, chunk):
        Diagnostic.__init__(self, data_manager)
        self.startdate = startdate
        self.member = member
        self.chunk = chunk
        self.required_vars = ['vo', 'uo']
        self.generated_vars = ['vsftbarot']

    @classmethod
    def generate_jobs(cls, diags, options):
        job_list = list()
        for startdate in diags.startdates:
            for member in diags.members:
                for chunk in range(1, diags.chunks + 1):
                    job_list.append(Psi(diags.data_manager, startdate, member, chunk))
        return job_list

    def compute(self):
        """
        Compute the barotropic stream function

        Created in March 2012         Author : vguemas@ic3.cat
        z
        :param input_file_u: input grid_U file name
        :rtype input_file_U: str
        :param input_file_v: input grid_V file name
        :rtype input_file_V: str
        :param output_file: output file name without nc extension  (=> 2D x-y)
        :rtype output_file: str
        """
        temp = TempFile.get()
        input_file_u = self.data_manager.get_file('ocean', 'uo', self.startdate, self.member, self.chunk)
        input_file_v = self.data_manager.get_file('ocean', 'vo', self.startdate, self.member, self.chunk)
        cdftools.run('cdfpsi', input=[input_file_u, input_file_v], output=temp, options='-mean -mask')
        Utils.rename_variable(temp, 'sobarstf', 'vsftbarot')
        Utils.setminmax(temp, 'vsftbarot')
        self.data_manager.send_file(temp, 'ocean', 'vsftbarot', self.startdate, self.member, self.chunk)
